==> pepperpy-1.3.2.tar.gz: pepperpy-1.3.2/pepperpy/files/handlers/pdf.py <==
"""PDF file handler implementation"""

from pathlib import Path
from typing import Any, Dict, Optional

import aiofiles

from ..exceptions import FileError
from ..types import FileContent, FileMetadata, PDFDocument
from .base import BaseHandler


class PDFHandler(BaseHandler):
    """Handler for PDF files"""

    async def read(self, path: Path) -> FileContent:
        """Read PDF file"""
        try:
            metadata = await self._get_metadata(path)
            # Lê o arquivo em modo binário usando aiofiles
            async with aiofiles.open(path, mode="rb") as f:
                content = await f.read()

            # Parse PDF content
            pdf_content: PDFDocument = self._parse_pdf(content)

            return FileContent(content=pdf_content, metadata=metadata.metadata, format="pdf")
        except Exception as e:
            raise FileError(f"Failed to read PDF file: {str(e)}", cause=e)

    async def write(
        self, path: Path, content: PDFDocument, metadata: Optional[Dict[str, Any]] = None
    ) -> FileMetadata:
        """Write PDF file"""
        try:
            # Implementar a lógica de escrita do PDF
            content.save(str(path))
            return await self._get_metadata(path)
        except Exception as e:
            raise FileError(f"Failed to write PDF file: {str(e)}", cause=e)

    def _parse_pdf(self, content: bytes) -> PDFDocument:
        """Parse PDF content

        Args:
            content: Raw PDF content in bytes

        Returns:
            PDFDocument: Parsed PDF document

        Raises:
            NotImplementedError: PDF parsing not implemented
        """
        # Implementar a lógica de parsing do PDF
        raise NotImplementedError("PDF parsing not implemented")

==> pepperpy-1.3.3.tar.gz: pepperpy-1.3.3/pepperpy/files/handlers/pdf.py <==
"""PDF file handler implementation"""

from pathlib import Path
from typing import Any

import aiofiles

from ..exceptions import FileError
from ..types import FileContent, FileMetadata, PDFDocument
from .base import BaseHandler


class PDFHandler(BaseHandler):
    """Handler for PDF files"""

    async def read(self, path: Path) -> FileContent:
        """Read PDF file"""
        try:
            metadata = await self._get_metadata(path)
            # Lê o arquivo em modo binário usando aiofiles
            async with aiofiles.open(path, mode="rb") as f:
                content = await f.read()

            # Parse PDF content
            pdf_content: PDFDocument = self._parse_pdf(content)

            return FileContent(content=pdf_content, metadata=metadata.metadata, format="pdf")
        except Exception as e:
            raise FileError(f"Failed to read PDF file: {e!s}", cause=e)

    async def write(
        self, path: Path, content: PDFDocument, metadata: dict[str, Any] | None = None,
    ) -> FileMetadata:
        """Write PDF file"""
        try:
            # Implementar a lógica de escrita do PDF
            content.save(str(path))
            return await self._get_metadata(path)
        except Exception as e:
            raise FileError(f"Failed to write PDF file: {e!s}", cause=e)

    def _parse_pdf(self, content: bytes) -> PDFDocument:
        """
        Parse PDF content

        Args:
            content: Raw PDF content in bytes

        Returns:
            PDFDocument: Parsed PDF document

        Raises:
            NotImplementedError: PDF parsing not implemented

        """
        # Implementar a lógica de parsing do PDF
        raise NotImplementedError("PDF parsing not implemented")
